(*
 * The LOOP Project
 *
 * The LOOP Team, Dresden University and Nijmegen University
 *
 * Copyright (C) 2002
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License in file COPYING in this or one of the
 * parent directories for more details.
 *
 * Created 14.5.99 by Hendrik
 *
 * Time-stamp: <Wednesday 15 May 02 17:08:10 tews@ithif51>
 *
 * component pass for CCSL
 *
 * $Id: component_pass.mli,v 1.5 2002/05/22 13:42:39 tews Exp $
 *
 *)

open Top_variant_types
open Classtypes;;


 (*******************************************************************
  *
  * interface for component pass
  *)


val class_component_pass : ccsl_iface_type -> unit

val adt_component_pass : ccsl_iface_type -> unit

val sig_component_pass : ccsl_iface_type -> unit


(*** Local Variables: ***)
(*** version-control: t ***)
(*** kept-new-versions: 5 ***)
(*** delete-old-versions: t ***)
(*** time-stamp-line-limit: 30 ***)
(*** End: ***)

